@@ -17,14 +17,15 @@ my(%option);
 
 if ($option_parser -> getoptions
 (
- \%option,
- 'help',
- 'lexed_file=s',
- 'maxlevel=s',
- 'minlevel=s',
- 'output_file=s',
- 'parsed_file=s',
- 'report_items=i',
+	\%option,
+	'help',
+	'lexed_file=s',
+	'maxlevel=s',
+	'minlevel=s',
+	'output_file=s',
+	'parsed_file=s',
+	'report_forest=i',
+	'report_items=i',
 ) )
 {
 	pod2usage(1) if ($option{'help'});
@@ -55,6 +56,7 @@ parse.pl [options]
 	-minlevel logOption2
 	-output_file aRenderedOutputFileName
 	-parsed_file aParsedOutputFileName
+	-report_forest $Boolean
 	-report_items $Boolean
 
 Exit value: 0 for success, 1 for failure. Die upon error.
@@ -113,6 +115,12 @@ Default: ''.
 
 The default means the file is not written.
 
+=item -report_forest $Boolean
+
+Log the globals, nodes and edges recognized in the lexed file.
+
+Default: 0.
+
 =item -report_items $Boolean
 
 Log the items recognized by the parser.
